#!/usr/bin/python2
# encoding: utf-8
#
# This file is a part of the CaosDB Project.
#
# Copyright (C) 2019 Henrik tom Wörden
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program. If not, see <https://www.gnu.org/licenses/>.
#

import pytest
from nose.tools import assert_equals, with_setup

import caosdb as db


def setup():
    rt = db.RecordType("Test")
    rt.insert()
    p = db.Property("te", datatype=db.TEXT)
    p.insert()


def teardown():
    try:
        db.execute_query("FIND Test*").delete()
    except Exception as e:
        print(e)
    try:
        db.execute_query("FIND te").delete()
    except Exception as e:
        print(e)


@pytest.mark.skip(reason="this is the confirmation for https://gitlab.com/caosdb/caosdb-server/issues/33")
@with_setup(setup, teardown)
def test_empty_string():
    r = db.Record()
    r.add_parent("Test")
    r.add_property("te", value="leer")
    r.insert()
    assert_equals(db.execute_query("FIND Test with te='leer'")[0].id, r.id)
    r.delete()
    r = db.Record()
    r.add_parent("Test")
    r.add_property("te", value="")
    r.insert()
    assert_equals(db.execute_query("FIND Test with te=''")[0].id, r.id)
    r.delete()
